@@ -1240,8 +1240,8 @@ _GROUP_ATTRIB_HANDLERS = {
     "stroke-miterlimit": _inherit_copy,
     "stroke-dasharray": _inherit_copy,
     "stroke-dashoffset": _inherit_copy,
-    "stroke-opacity": _inherit_multiply,
-    "fill-opacity": _inherit_multiply,
+    "stroke-opacity": _inherit_copy,
+    "fill-opacity": _inherit_copy,
     "opacity": _inherit_multiply,
     "clip-path": _inherit_clip_path,
     "id": _do_not_inherit,
